==> asksuite-core-1.0.163.tgz: package/generic.crawler.js <==
let requestPromise = require('request-promise-native');
const Global = require('./global');


module.exports = function (config) {

    var requester = {};

    const AsksuiteService = require('./infochat.service')(config);

    requester.search = async function (type, idHotel, checkin, checkout, adultos, criancas, cupom, childAges,otherParams) {

        try {

            //vai buscar no nosso banco de dados os motores registrados com o type X;
            let BookingEngine = await AsksuiteService.findBookingEngineByType(type);

            let options = {
                uri: Global.CRAWLER_ENDPOINT + '/generic/'+BookingEngine.urlPath,
                qs: {
                    idHotel: idHotel,
                    checkin: checkin,
                    checkout: checkout,
                    adultos: adultos,
                    criancas: criancas,
                    cupom: cupom,
                    childAges: childAges,
                    otherParams: otherParams
                },
                json: true // Automatically parses the JSON string in the response
            };

            let response = await requestPromise.get(options);

            return Promise.resolve(response);

        } catch (err) {
            console.log("caiu aqui no erro");
            console.error(err.error);
            return Promise.reject(err.error);
        }
    }


    requester.getSuggestionDates = async function (type, idHotel, checkin, checkout, adultos, criancas, cupom, childAges, otherParams) {

        try {

            let BookingEngine = await AsksuiteService.findBookingEngineByType(type);


            let options = {
                uri: Global.CRAWLER_ENDPOINT+ '/generic/'+BookingEngine.urlPath+'/suggestion',
                qs: {
                    idHotel: idHotel,
                    checkin: checkin,
                    checkout: checkout,
                    adultos: adultos,
                    criancas: criancas,
                    cupom: cupom,
                    childAges: childAges,
                    otherParams: otherParams
                },
                json: true // Automatically parses the JSON string in the response
            };

            let response = await requestPromise.get(options);

            return Promise.resolve(response);

        } catch (err) {
            console.log("caiu aqui no erro");
            console.error(err.error);
            return Promise.reject(err.error);
        }



    }


    return requester;

}

==> asksuite-core-2.5.0.tgz: package/generic.crawler.js <==
let requestPromise = require('request-promise-native');
const Global = require('./global');


module.exports = function (config) {

    var requester = {};

    const AsksuiteService = require('./infochat.service')(config);

    requester.search = async function (type, idHotel, checkin, checkout, adultos, criancas, cupom, childAges,otherParams) {

        try {

            //vai buscar no nosso banco de dados os motores registrados com o type X;
            let BookingEngine = await AsksuiteService.findBookingEngineByType(type);

            let options = {
                uri: Global.CRAWLER_ENDPOINT + '/generic/'+BookingEngine.urlPath,
                qs: {
                    idHotel: idHotel,
                    checkin: checkin,
                    checkout: checkout,
                    adultos: adultos,
                    criancas: criancas,
                    cupom: cupom,
                    childAges: childAges,
                    otherParams: otherParams
                },
                json: true // Automatically parses the JSON string in the response
            };

            let response = await requestPromise.get(options);

            return Promise.resolve(response);

        } catch (err) {
            console.log("caiu aqui no erro");
            console.error(err.error);
            return Promise.reject(err.error);
        }
    }


    requester.getSuggestionDates = async function (type, idHotel, checkin, checkout, adultos, criancas, cupom, childAges, otherParams) {

        try {

            let options = {
                uri: Global.CRAWLER_ENDPOINT+ '/generic/generic/suggestion',
                qs: {
                    idHotel: idHotel,
                    checkin: checkin,
                    checkout: checkout,
                    adultos: adultos,
                    criancas: criancas,
                    cupom: cupom,
                    childAges: childAges,
                    otherParams: otherParams,
                    crawlerName: type
                },
                json: true // Automatically parses the JSON string in the response
            };

            let response = await requestPromise.get(options);

            return Promise.resolve(response);

        } catch (err) {
            console.log("caiu aqui no erro");
            console.error(err.error);
            return Promise.reject(err.error);
        }



    }


    return requester;

}
